hotspot/src/cpu/x86/vm/macroAssembler_x86.cpp
changeset 35201 996db89f378e
parent 35071 a0910b1d3e0d
child 35214 d86005e0b4c2
--- a/hotspot/src/cpu/x86/vm/macroAssembler_x86.cpp	Fri Dec 18 13:38:49 2015 +0000
+++ b/hotspot/src/cpu/x86/vm/macroAssembler_x86.cpp	Sun Dec 20 10:37:23 2015 -0500
@@ -1059,8 +1059,8 @@
   // touch it again.  (It was touched as (tmp-pagesize) but then tmp
   // was post-decremented.)  Skip this address by starting at i=1, and
   // touch a few more pages below.  N.B.  It is important to touch all
-  // the way down to and including i=StackShadowPages.
-  for (int i = 1; i < StackShadowPages; i++) {
+  // the way down including all pages in the shadow zone.
+  for (int i = 1; i < ((int)JavaThread::stack_shadow_zone_size() / os::vm_page_size()); i++) {
     // this could be any sized move but this is can be a debugging crumb
     // so the bigger the better.
     movptr(Address(tmp, (-i*os::vm_page_size())), size );